Reporting Bugs — mod_wsgi 4.8.0 documentation

# Reporting Bugs

If you believe you have uncovered a bug in mod_wsgi code then lodge a bug report on the mod_wsgi issue tracker. The issue tracker is located on GitHub at:

- https://github.com/GrahamDumpleton/mod_wsgi/issues

Before creating a ticket on the issue tracker, please do try and ensure you attempt to resolve issues using the mod_wsgi mailing list first as explained in Finding Help. The majority of issues lodged via the issue tracker are not actually bugs in mod_wsgi but due to external factors or simply a failure to read the documentation.